# V1alpha1ArtifactoryAuth

ArtifactoryAuth describes the secret selectors required for authenticating to artifactory
## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**password_secret** | [**IoK8sApiCoreV1SecretKeySelector**](IoK8sApiCoreV1SecretKeySelector.md) |  | [optional] 
**username_secret** | [**IoK8sApiCoreV1SecretKeySelector**](IoK8sApiCoreV1SecretKeySelector.md) |  | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


